package com.stellvoy.api.client.learning;

import com.stellvoy.api.client.learning.fallback.LearningClientFallback;
import com.stellvoy.api.dto.leanring.LearningInterestDTO;
import com.stellvoy.api.dto.leanring.LearningLessonDTO;
import com.stellvoy.api.dto.leanring.LearningMedalDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.ArrayList;
import java.util.List;

@FeignClient(value = "learning-service", fallbackFactory = LearningClientFallback.class)
public interface LearningClient {
    /**
     * 根据勋章id集合查询勋章信息
     */
    @GetMapping("/medal/{ids}")
    List<LearningMedalDTO> queryMedalByIds(@PathVariable("ids") ArrayList<Long> ids);
    /**
     * 查询所有勋章信息
     */
    @GetMapping("/medal")
    List<LearningMedalDTO> queryMedal();
    /**
     * 根据兴趣标签id集合查询兴趣标签
     */
    @GetMapping("/interest/{ids}")
    List<LearningInterestDTO> queryInterestByIds(@PathVariable("ids") ArrayList<Long> ids);
    /**
     * 查询所有兴趣标签
     */
    @GetMapping("/interest")
    List<LearningInterestDTO> queryInterest();
    /**
     * 统计课程学习人数
     * @param courseId 课程id
     * @return 学习人数
     */
    @GetMapping("/lessons/{courseId}/count")
    Integer countLearningLessonByCourse(@PathVariable("courseId") Long courseId);

    /**
     * 校验当前用户是否可以学习当前课程
     * @param courseId 课程id
     * @return lessonId，如果是报名了则返回lessonId，否则返回空
     */
    @GetMapping("/lessons/{courseId}/valid")
    Long isLessonValid(@PathVariable("courseId") Long courseId);

    /**
     * 查询当前用户指定课程的学习进度
     * @param courseId 课程id
     * @return 课表信息、学习记录及进度信息
     */
    @GetMapping("/learning-records/course/{courseId}")
    LearningLessonDTO queryLearningRecordByCourse(@PathVariable("courseId") Long courseId);

}
