package com.stellvoy.api.client.user;


import com.stellvoy.api.client.user.fallback.UserClientFallback;
import com.stellvoy.api.dto.user.LoginFormDTO;
import com.stellvoy.api.dto.user.NewUserDTO;
import com.stellvoy.common.domain.dto.LoginUserDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;


@FeignClient(value = "user-service", fallbackFactory = UserClientFallback.class)
public interface UserClient {
    /**
     * 根据id查询用户信息
     */
    @GetMapping("/users/{id}")
    NewUserDTO queryUserById(@PathVariable("id") Long id);
    /**
     * 根据id查询用户信息
     */
    @GetMapping("/users/list/{ids}")
    List<NewUserDTO> queryUserByIds(@PathVariable("ids") List<Long> ids);
    /**
     * 根据手机号查询用户id
     * @param phone 手机号
     * @return 用户id
     */
    @GetMapping("/users/ids")
    Long exchangeUserIdWithPhone(@RequestParam("phone") String phone);

    /**
     * 登录接口
     * @param loginDTO 登录信息
     * @param isStaff 是否是员工
     * @return 用户详情
     */
    @PostMapping("/users/detail/{isStaff}")
    LoginUserDTO queryUserDetail(@RequestBody LoginFormDTO loginDTO, @PathVariable("isStaff") boolean isStaff);
}