package com.stellvoy.task.controller;

import com.stellvoy.api.dto.task.NewTaskDTO;
import com.stellvoy.common.utils.BeanUtils;
import com.stellvoy.task.entity.IncomeEntity;
import com.stellvoy.task.util.PageInfo;
import com.stellvoy.task.entity.TaskEntity;
import com.stellvoy.task.service.TaskService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/task")
public class TaskController {
    @Autowired
    private TaskService taskService;
    /**
     * 根据id查询用户信息
     */
    @GetMapping("/{id}")
    public NewTaskDTO queryUserById(@PathVariable("id") Long id) {
        TaskEntity one = taskService.lambdaQuery().eq(TaskEntity::getId, id).one();
        return BeanUtils.copyBean(one, NewTaskDTO.class);
    }
    /**
     * 根据id集合查询用户信息
     */
    @GetMapping("/list/{ids}")
    public List<NewTaskDTO> queryUserByIds(@PathVariable("ids") List<Long> ids) {
        List<TaskEntity> userList = taskService.lambdaQuery().in(TaskEntity::getId, ids).list();
        return BeanUtils.copyList(userList, NewTaskDTO.class);
    }
    /**
     * 根据用户ID获取任务列表
     * @param userId
     * @return
     */
    @GetMapping("/byLabel/{userId}")
    public List<TaskEntity> getTasksByUserId(@PathVariable Long userId) {
        return taskService.getTasksByUserId(userId);
    }
    /**
     * 分页获取用户的任务列表
     * @param userId
     * @param pageNumber
     * @param pageSize
     * @return
     */
    @GetMapping("/myTaskByUserId/{userId}")
    public PageInfo<TaskEntity> getMyTasksByUserId(@PathVariable Long userId,
                                                   @RequestParam(defaultValue = "1") int pageNumber,
                                                   @RequestParam(defaultValue = "8") int pageSize) {
        // 调整pageNumber为0-based索引
        int currentPage = pageNumber - 1;
        return taskService.getMyTasksByUserIdWithPagination(userId, currentPage, pageSize);
    }

    /**
     * 获取前五名用户收入和当前用户收入
     * @param userId
     * @return
     */
    @GetMapping("/getFindTopUserIncome/{userId}")
    public Map<String, Object> getFindTopFiveAndCurrentUserIncome(@PathVariable Long userId) {
        return taskService.getFindTopFiveAndCurrentUserIncome(userId);
    }
}
