package com.stellvoy.task.service.serviceImpl;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.stellvoy.api.client.user.UserClient;
import com.stellvoy.api.dto.user.NewUserDTO;
import com.stellvoy.task.entity.IncomeEntity;
import com.stellvoy.task.entity.LabelEntity;
import com.stellvoy.task.entity.TaskEntity;
import com.stellvoy.task.entity.UserTaskEntity;
import com.stellvoy.task.mapper.TaskMapper;
import com.stellvoy.task.service.TaskService;
import com.stellvoy.task.util.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;

import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

@Service
public class TaskServiceImpl extends ServiceImpl<TaskMapper, TaskEntity> implements TaskService {
    @Autowired
    private TaskMapper taskMapper;
    @Autowired
    private UserClient userClient;

    @Override
    public List<TaskEntity> getTasksByUserId(Long userId) {
        //当前用户未登录的情况下,根据最新创建时间推送八条任务数据
        if (userId == 0) {
            return taskMapper.findTopEightEnabledTasks();// 参数校验失败
        }

        LambdaQueryWrapper<LabelEntity> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(LabelEntity::getId, userId);
        // 查询任务列表
        return taskMapper.findTasksByUserId(userId);
    }



    @Override
    public PageInfo<TaskEntity> getMyTasksByUserIdWithPagination(Long userId, int pageNumber, int pageSize) {
        // 获取总记录数
        int total = taskMapper.countMyTasksByUserId(userId);

        // 计算当前页码
//        int currentPage = pageNumber - 1; // MyBatis的LIMIT参数从0开始计数

        // 查询当前页的数据
        List<TaskEntity> tasks = taskMapper.findMyTasksByUserId(userId, pageNumber * pageSize, pageSize);

        // 封装分页信息
        return new PageInfo<>(tasks, total, pageNumber, pageSize);
    }

    @Override
    public int getTotalTaskCount(Long userId) {
        return taskMapper.countMyTasksByUserId(userId);
    }

    @Override
    public Map<String, Object> getFindTopFiveAndCurrentUserIncome(Long userId) {
        if (userId == null) {
            return Collections.emptyMap(); // 参数校验失败
        }

        try {
            // 创建临时表
            taskMapper.createTopFiveUsersTempTable(userId);

            // 查询任务
            List<UserTaskEntity> personIncomes = taskMapper.findTopFiveAndCurrentUserIncome(userId);

            // 提取所有用户ID
            List<Long> userIds = personIncomes.stream()
                    .map(UserTaskEntity::getUserId)
                    .collect(Collectors.toList());

            // 批量查询用户信息
            List<NewUserDTO> users = userClient.queryUserByIds(userIds);

            // 将用户ID与用户信息映射到Map中
            Map<Long, NewUserDTO> userMap = users.stream()
                    .collect(Collectors.toMap(NewUserDTO::getId, user -> user));

            List<IncomeEntity> userEntitys = new ArrayList<>();
            for (UserTaskEntity userTaskEntity : personIncomes) {
                IncomeEntity income = new IncomeEntity();
                Long id = userTaskEntity.getUserId();
                NewUserDTO user = userMap.get(id);
                if (user != null) {
                    income.setUserId(String.valueOf(id));
                    income.setUserName(user.getUsername());
                    income.setSex(user.getSex());
                    // 其他字段的映射
                }
                userEntitys.add(income);
            }

            // 封装结果
            Map<String, Object> result = new HashMap<>();
            result.put("personIncomes", personIncomes);
            result.put("userEntitys", userEntitys);

            return result;
        } catch (Exception e) {
            // 异常处理
            log.error("Error occurred while fetching top five and current user income: ", e);
            throw e;
        } finally {
            // 删除临时表
            taskMapper.dropTopFiveUsersTempTable(userId);
        }
    }





}