package com.stellvoy.user.service.impl;

import com.aliyun.dysmsapi20170525.models.SendSmsResponse;
import com.stellvoy.user.service.ICodeService;
import com.stellvoy.user.utils.SmsService;
import com.stellvoy.user.utils.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.HttpClientBuilder;
import org.apache.http.util.EntityUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.http.HttpMethod;
import org.springframework.stereotype.Service;
import javax.crypto.Mac;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import java.io.*;
import java.net.URLEncoder;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.TimeUnit;

@Slf4j
@Service
public class CodeServiceImpl implements ICodeService {

    @Autowired
    private StringRedisTemplate stringRedisTemplate;
    @Autowired
    private SmsService smsService;
    private static final Logger LOGGER = LogManager.getLogger(UserServiceImpl.class);
    @Override
    public void sendVerifyCode(String phone) {
        String cleanedPhone = phone.replaceAll("\\D+", "");

        // 手机号格式校验
        if (!cleanedPhone.matches("^1[3-9]\\d{9}$")) {
            throw new IllegalArgumentException("手机号格式错误");
        }
        // 生成验证码
        String code = generateVerificationCode();
        String templateCode = "SMS_299785998";
        String signName="昆山星途旗航人工智能科技";
        try {
            SendSmsResponse response = smsService.sendVerificationCode(cleanedPhone, signName, templateCode, "{\"code\":\"" + code + "\"}");
            if (!response.getBody().getCode().equals("OK")) {
                LOGGER.error("发送短信失败: {}", response.getBody().getMessage());
                throw new RuntimeException("发送短信失败");
            }
        } catch (Exception e) {
            LOGGER.error("发送短信异常", e);
            throw new RuntimeException("发送短信异常");
        }
        // 将验证码存储到Redis，并设置过期时间为5分钟
        stringRedisTemplate.opsForValue().set("verificationCode:" + cleanedPhone, code, 5, TimeUnit.MINUTES);
    }

    @Override
    public void verifyCode(String phone, String code) {
        // 从Redis中获取验证码
        String storedCode = stringRedisTemplate.opsForValue().get("verificationCode:" + phone);
        // 验证码校验
        if (storedCode == null || !storedCode.equals(code)) {
            throw new RuntimeException("验证码错误或已过期");
        }
        // 验证码正确，清空Redis中的验证码
        stringRedisTemplate.delete("verificationCode:" + phone);
    }

    /**
     * 邮箱验证码
     */
    private static final String ACCESS_KEY_ID = System.getenv("ALIBABA_CLOUD_ACCESS_KEY_ID");
    private static final String AccessKeySecret  = System.getenv("ALIBABA_CLOUD_ACCESS_KEY_SECRET");
    private static final String VERSION = "2015-11-23";
    private static final String ACTION = "SingleSendMail";
    private static final String SIGNATURE_METHOD = "HMAC-SHA1";
    private static final String SIGNATURE_VERSION = "1.0";
    private static final String FORMAT = "JSON";
    private static final String REGION_ID = "cn-hangzhou";

    public void sendEmailCode(String email) {
        String code = generateVerificationCode();
        SortedMap<String, Object> params = new TreeMap<>();
        params.put("AccessKeyId", ACCESS_KEY_ID);
        params.put("Action", ACTION);
        params.put("Format", FORMAT);
        params.put("RegionId", REGION_ID);
        params.put("SignatureMethod", SIGNATURE_METHOD);
        params.put("SignatureNonce", UUID.randomUUID().toString());
        params.put("SignatureVersion", SIGNATURE_VERSION);
        params.put("Timestamp", getUTCTimeStr());
        params.put("Version", VERSION);
        params.put("AccountName", "labelx@freelancer.stellvoy.com");
        params.put("AddressType", "1");
        params.put("HtmlBody", emailBody(code));
        params.put("ReplyToAddress", Boolean.TRUE);
        params.put("Subject", "emailCode");
        params.put("TagName", "code");
        params.put("ToAddress", email);
        httpRequestSendEmail(params);
        stringRedisTemplate.opsForValue().set("verificationCode:" + email, code, 10, TimeUnit.MINUTES);
    }
    private final static HttpMethod method = HttpMethod.POST;
    private final static String protocol = "https";
    private final static String host = "dm.aliyuncs.com";
    public void httpRequestSendEmail(Map<String, Object> params) {
        String result = null;
        try {
            params.put("Signature", getSignature(prepareParamStrURLEncoder(params), method));
            String param = prepareParamStrURLEncoder(params);
            String url = protocol + "://" + host + "/?" + param;

            HttpClient httpClient = HttpClientBuilder.create().build();
            HttpResponse response = null;
            if (method.equals(HttpMethod.GET)) {
                HttpGet request = new HttpGet(url);
                response = httpClient.execute(request);
            } else {
                HttpPost request = new HttpPost(url);
                response = httpClient.execute(request);
            }
            if (null != response){
                result = EntityUtils.toString(response.getEntity());
            }

        } catch (ClientProtocolException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    public String prepareParamStrURLEncoder(Map<String, Object> params) {
        try {
            StringBuffer param = new StringBuffer();
            for (Map.Entry<String, Object> entry : params.entrySet()) {
                if (StringUtils.isBlank(entry.getKey()) || null == entry.getValue()) {
                    continue;
                }
                param.append(getUtf8Encoder(entry.getKey()) + "=" + getUtf8Encoder(entry.getValue().toString()) + "&");

            }
            return param.substring(0, param.lastIndexOf("&"));

        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }
    /**
     * 获取签名
     *
     * @param param
     * @param method
     * @return
     * @throws Exception
     */
    private String getSignature(String param, HttpMethod method) throws Exception {
        String toSign = method + "&" + URLEncoder.encode("/", "utf8") + "&"
                + getUtf8Encoder(param);
        byte[] bytes = HmacSHA1Encrypt(toSign, AccessKeySecret + "&");
        return Base64.getEncoder().encodeToString(bytes);
    }

    private String getUtf8Encoder(String param) throws UnsupportedEncodingException {
        return URLEncoder.encode(param, "utf8")
                .replaceAll("\\+", "%20")
                .replaceAll("\\*", "%2A")
                .replaceAll("%7E", "~");
    }

    private static final String MAC_NAME = "HmacSHA1";
    private static final String ENCODING = "UTF-8";

    /**
     * 使用 HMAC-SHA1 签名方法对encryptText进行签名
     *
     * @param encryptText 被签名的字符串
     * @param encryptKey  密钥
     * @return
     * @throws Exception
     */
    public static byte[] HmacSHA1Encrypt(String encryptText, String encryptKey) throws Exception {
        byte[] data = encryptKey.getBytes(ENCODING);
        //根据给定的字节数组构造一个密钥,第二参数指定一个密钥算法的名称
        SecretKey secretKey = new SecretKeySpec(data, MAC_NAME);
        //生成一个指定 Mac 算法的 Mac 对象
        Mac mac = Mac.getInstance(MAC_NAME);
        //用给定密钥初始化 Mac 对象
        mac.init(secretKey);

        byte[] text = encryptText.getBytes(ENCODING);
        //完成 Mac 操作
        return mac.doFinal(text);
    }

    private static DateFormat daetFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    /**
     * 得到UTC时间，类型为字符串，格式为"yyyy-MM-dd HH:mm"<br />
     * 如果获取失败，返回null
     *
     * @return
     */
    public static String getUTCTimeStr() {
        // 1、取得本地时间：
        Calendar cal = Calendar.getInstance();
        // 2、取得时间偏移量：
        int zoneOffset = cal.get(Calendar.ZONE_OFFSET);
        // 3、取得夏令时差：
        int dstOffset = cal.get(Calendar.DST_OFFSET);
        // 4、从本地时间里扣除这些差量，即可以取得UTC时间：
        cal.add(Calendar.MILLISECOND, -(zoneOffset + dstOffset));
        String date = daetFormat.format(cal.getTime());
        String[] strs = date.split(" ");
        return strs[0] + "T" + strs[1] + "Z";
    }
    private String emailBody(String verificationCode) {
        return "<div class=\"container\">"
                + "<h1>欢迎绑定您的邮箱</h1>"
                + "<p>感谢您注册并使用我们的服务！为了更好地享受我们的功能和服务，我们建议您绑定您的邮箱地址。这将帮助您更方便地接收重要通知、找回密码以及获取更多个性化服务。</p>"
                + "<p><br/></p>"
                + "<p style=\"text-align: center;\">"
                + "您的验证码为：<span class=\"code\">" + verificationCode + "</span>"
                + "</p>"
                + "<p><br/></p>"
                + "<p>请您在接下来的 10 分钟内使用此验证码完成邮箱绑定操作。如果这不是您本人的操作，请忽略此邮件。</p>"
                + "<p>如果您在绑定过程中遇到任何问题，请随时联系我们的客服团队，我们将竭诚为您服务。</p>"
                + "<p>再次感谢您的支持！</p>"
                + "<p>祝您使用愉快！</p>"
                + "</div>";
    }
    private String generateVerificationCode() {
        StringBuilder sb = new StringBuilder();
        Random random = new Random();
        for (int i = 0; i < 6; i++) {
            sb.append(random.nextInt(10));
        }
        return sb.toString();
    }
}
